reusable_image_widget library
Classes
- AppAvatar
- A unified avatar widget that renders either a circular or rectangular avatar based on isCircle flag. Designed to be highly reusable and customizable.
- AppAvatarImage
- AppCircleAvatar
- AppImageLoader
- Builds image widget from either picked file or image source
- AppImageResolver
- AppImageViewer
- AppRectangleAvatar
- AvatarStyleConstants
- AvatarWithOnlineIndicator
- EditProfileIcon
- EditProfileImageViewer
- FullScreenImageViewer
- HeroWrapper
- Wraps widget in Hero if tag is provided
- PhotoViewImage
Extensions
Constants
- kLogoIconPath → const String
- kProfileIconPath → const String
- kProfileIconUrl → const String
- kRadius → const double
- noImageAvailable → const String
Functions
-
appImageProvider(
{String? imageSource, XFile? pickedFile, double? scale}) → ImageProvider< Object> ?